/// <reference types="@nasl/types" />

namespace nasl.ui {
    @Component({
        title: '图标',
        icon: 'icon',
        description: '图标',
        group: "Display"
    })
    export class IIco extends ViewComponent {

        constructor(options?: Partial<IIcoOptions>) { super(); }
    }

    export class IIcoOptions extends ViewComponentOptions {
        @Prop({
            group: '主要属性',
            title: '图标',
            docDescription: '支持从图标库选择图标或上传自定义图标。',
            setter: {
                concept: 'IconSetter',
            },
        })
        name: nasl.core.String = '';

        @Prop({
            group: '主要属性',
            title: '图标布局',
            description: '图标和文本的布局方式',
            docDescription: '支持选择图标的展示方式，包括仅图标、组合图标-上下、组合图标-左右三种方式。',
            setter: {
                concept: 'EnumSelectSetter',
                options: [{ title: '仅图标' }, { title: '组合图标-上下' }, { title: '组合图标-左右' }],
            },
        })
        icotype: 'only' | 'top' | 'left' = 'top';

        @Prop({
            group: '交互属性',
            title: '链接类型',
            docDescription: '支持页面跳转、普通链接、下载链接。',
            bindHide: true,
            setter: {
                concept: 'EnumSelectSetter',
                options: [{ title: '页面跳转' }, { title: '下载链接' }],
            },
        })
        linkType: 'destination' | 'download' = 'destination';

        @Prop({
            group: '交互属性',
            title: '链接地址',
            docDescription: '链接的详细地址。',
        })
        hrefAndTo: nasl.core.String;

        @Prop({
            group: '交互属性',
            title: '链接打开方式',
            description: '链接跳转的打开方式，父级窗口和顶级窗口仅适用于iframe组件嵌套的情况，若不存在嵌套，则其打开方式同当前窗口。',
            docDescription: '可选新窗口、父级窗口、当前窗口和顶级窗口，其中父级窗口和顶级窗口仅适用于iframe组件嵌套的情况，若不存在嵌套，则打开方式同当前窗口。',
            setter: {
                concept: 'EnumSelectSetter',
                options: [{ title: '新窗口' }, { title: '当前窗口' }, { title: '父级窗口' }, { title: '顶级窗口' }],
            },
        })
        target: '_blank' | '_self' | '_parent' | '_top' = '_self';

        @Event({
            title: '点击后',
            description: '点击此项时触发',
        })
        onClick: () => any;

        @Event({
            title: '双击',
            description: '双击此项时触发',
        })
        onDblclick: () => any;

        @Event({
            title: '右键点击',
            description: '右键点击此项时触发',
        })
        onRightclick: () => any;

        @Event({
            title: '鼠标移入',
            description: '鼠标移入此项时触发',
        })
        onOver: () => any;

        @Event({
            title: '鼠标移出',
            description: '鼠标移出此项时触发',
        })
        onOut: () => any;

        @Event({
            title: '鼠标按下',
            description: '鼠标按下此项时触发',
        })
        onDown: () => any;

        @Slot({
            title: '默认',
            description: '插入文本或 HTML。',
        })
        slotDefault: () => Array<ViewComponent>;
    }
}
